/**
 * 工具函数
 */

const _path = require("path");
const fs = require("fs");
const rm = require("rimraf");
const copy = require("copy-concurrently");

module.exports = {
  /**
   * 创建文件目录
   * @param dirname
   * @return {boolean}
   */
  mkdir(dirname) {
    if (fs.existsSync(dirname)) {
      return true;
    } else {
      if (this.mkdir(_path.dirname(dirname))) {
        fs.mkdirSync(dirname);
        return true;
      }
    }
  },
  /**
   * 写文件
   * @param path
   * @param content
   */
  writeFile(path, content) {
    this.mkdir(_path.dirname(path));
    fs.writeFileSync(path, content, "utf-8");
  },
  /**
   * 复制单个文件
   * @param from
   * @param to
   */
  copyFile(from, to) {
    this.mkdir(_path.dirname(to));
    fs.copyFileSync(from, to);
  },
  /**
   * 复制目录下全部文件，不递归
   * @param fromDir
   * @param toDir
   */
  copyFiles(fromDir, toDir) {
    if (!fs.existsSync(fromDir)) {
      return;
    }
    const files = fs.readdirSync(fromDir) || [];
    files.forEach((file) => {
      const from = this.join(fromDir, file);
      const to = this.join(toDir, file);
      this.copyFile(from, to);
    });
  },
  /**
   * 递归获取文件路径数组
   * @param {string} dir
   */
  getFiles(dir) {
    let result = [];
    const files = fs.readdirSync(dir) || [];
    files.forEach((file) => {
      const fullPath = this.join(dir, file);
      const stat = fs.statSync(fullPath);
      if (stat.isDirectory()) {
        result = result.concat(this.getFiles(fullPath));
      } else {
        result.push(fullPath);
      }
    });
    return result;
  },
  /**
   * 删除文件和文件夹
   * @param path
   */
  rm(path) {
    rm.sync(path);
  },
  /**
   * 复制文文件夹和文件
   * @param from
   * @param to
   */
  copy(from, to) {
    if (fs.existsSync(to)) {
      this.rm(to);
    }
    return copy(from, to);
  },

  /**
   * 生产唯一id
   * @returns {string}
   */
  uid() {
    return new Date().getTime().toString() + Math.floor(Math.random() * 1000);
  },
};
